//
//
//  mixer :- silently sets the soundcard mixer volumes via OSS
//           handy for system initialisation
// 
//  written by Simon Aldrich (simon@simonaldrich.co.uk) 
//
//////////////////////////////////////////////////////////////////

#include <stdio.h>
#include <string.h>
#include "devmixer.h"

#define MIXER_DEVICE "/dev/mixer"

void usage(char *progname)
{
	printf("\n%s :- adjust mixer settings via OSS\n", progname);
	printf("\tUsage: %s <mixerdevice> <settings>\n", progname);
	printf("Uses %s by default and looks for settings in ~/.mixer.conf & /etc/mixer.conf\n", MIXER_DEVICE);
}

int main(int argc, char **argv)
{
	devmixer	*mixerdev;
	char		*homedir, *settings = NULL;
	FILE		*exists = NULL;

	// figure out what we should do
	switch (argc)
	{
		// no parameters
		case 1:
			mixerdev = new devmixer(MIXER_DEVICE);
			break;
		// mixer specified
		case 2:
			mixerdev = new devmixer(argv[1]);
			break;
		// mixer and settings file specified
		case 3:
			mixerdev = new devmixer(argv[1]);
			settings = (char*) calloc(strlen(argv[2]), sizeof(char));
			strcpy(settings, argv[2]);
			break;
		// no idea what to do so print usage statement
		default:
			usage(argv[0]);
			exit(0);
			break;
	}
	
	// if we haven't been told which settings file to use
	if (settings == NULL)
	{
		// attempt to open a mixer.conf file in the home directory
		// $HOME should be defined in pretty much everything these days
		homedir = getenv("HOME");
		settings = (char*) calloc(strlen(homedir)+14, sizeof(char));
		strcpy(settings, homedir);
		strcat(settings, "/.mixer.conf");
		exists = fopen(settings, "rb");
		
		if (exists == NULL)
		{
			// then something was wrong with that file
			free(settings);
			settings = NULL;
			
			exists = fopen("/etc/mixer.conf", "rb");
			if (exists != NULL)
			{
				fclose(exists);
				settings = (char*) calloc(16, sizeof(char));
				strcpy(settings, "/etc/mixer.conf");				
			}
		}
		else
		{
			fclose(exists);
		}
	}
	
	if (settings != NULL)
	{
		mixerdev->load_mixer_settings(settings);
		free(settings);
	}
	else
	{
		mixerdev->save_mixer_settings();
	}
	
	// close the mixer
	delete mixerdev;
}
